Package: dsBetaTest
Title: New DataSHIELD Server Functions
Version: 0.2.0
Author: DataSHIELD Developers <datashield@newcastle.ac.uk>
Maintainer: DataSHIELD Developers <datashield@newcastle.ac.uk>
Description: Beta versions of new DataSHIELD server functions. Collected in this
    temporary package, prior to inclusion in the main DataSHIELD packages.
License: GPL-3
Depends: dsBase, dsStats, dsGraphics, dsModelling
AggregateMethods: meanSdGpDS, tTestFDS2, lexisDS1.o, glmDS1.o,
        glmDS2.o, covDS.o, asFactorDS1.o, meanDS.o, recodeValuesDS1.o,
        rilmDS.b, testObjExistsDS.o, listDisclosureSettingsDS.o
AssignMethods: lexisDS2.o, lexisDS3.o, asFactorDS2.o, BooleDS.o,
        recodeValuesDS2.o
RoxygenNote: 6.1.1
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2018-11-28 15:58:28 UTC; yannick
