# Generated by roxygen2: do not edit by hand

export(BooleDS.o)
export(asFactorDS1.o)
export(asFactorDS2.o)
export(covDS.o)
export(glmDS1.o)
export(glmDS2.o)
export(lexisDS1.o)
export(lexisDS2.o)
export(lexisDS3.o)
export(listDisclosureSettingsDS.o)
export(meanDS.o)
export(meanSdGpDS)
export(recodeValuesDS1.o)
export(recodeValuesDS2.o)
export(rilmDS.b)
export(tTestFDS2)
export(testObjExistsDS.o)
