% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lexisDS1.5.R
\name{lexisDS1.5}
\alias{lexisDS1.5}
\title{lexisDS1.5.R}
\usage{
lexisDS1.5(exitCol = NULL)
}
\description{
TODO
}

