% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lexisDS2.5.R
\name{lexisDS2.5}
\alias{lexisDS2.5}
\title{lexisDS2.5.R}
\usage{
lexisDS2.5(datatext = NULL, intervalWidth, maxmaxtime, idCol, entryCol,
  exitCol, statusCol, vartext = NULL)
}
\description{
TODO
}

