% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listDisclosureSettingsDS.o.R
\name{listDisclosureSettingsDS.o}
\alias{listDisclosureSettingsDS.o}
\title{listDisclosureSettingsDS}
\usage{
listDisclosureSettingsDS.o()
}
\description{
This serverside function is an aggregate function that is called by the
ds.listDisclosureSettings
}
\details{
For more details see the extensive header for ds.listDisclosureSettings
}
\author{
Paul Burton
}
